@@ -16,9 +16,9 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-import gobject
+from gi.repository import GObject
 from gi.repository import Gtk
-from gettext import gettext as _
+from gnomedvb import _
 
 from gnomedvb import seconds_to_time_duration_string
 from gnomedvb.ui.widgets.RecordingsStore import RecordingsStore
@@ -27,20 +27,21 @@ from gnomedvb.ui.widgets.CellRendererDatetime import CellRendererDatetime
 class RecordingsView(Gtk.TreeView):
 
     def __init__(self, model=None):
-        gobject.GObject.__init__(self)
+        GObject.GObject.__init__(self)
         if model != None:
             self.set_model(model)      
 
+        self._append_text_column(_("Title"), RecordingsStore.COL_NAME)
+        self._append_text_column(_("Channel"), RecordingsStore.COL_CHANNEL)
+        
+        col_length, cell_length = self._append_text_column(_("Length"),
+            RecordingsStore.COL_DURATION)
+        col_length.set_cell_data_func(cell_length, self._get_length_data, None)
+
         cell = CellRendererDatetime()
         col = Gtk.TreeViewColumn(_("Start"), cell,
             datetime=RecordingsStore.COL_START)
         self.append_column(col)
-        self._append_text_column(_("Channel"), RecordingsStore.COL_CHANNEL)
-        self._append_text_column(_("Title"), RecordingsStore.COL_NAME)
-        
-        col_length, cell_length = self._append_text_column(_("Length"),
-            RecordingsStore.COL_DURATION)
-        col_length.set_cell_data_func(cell_length, self._get_length_data, None)
             
     def _append_text_column(self, title, col_index):
         cell = Gtk.CellRendererText()
