@@ -20,10 +20,11 @@ import os
 import os.path
 from gi.repository import Gdk
 from gi.repository import Gtk
-import gobject
+from gi.repository import GLib
+from gi.repository import GObject
 import gettext
 import locale
-from gettext import gettext as _
+from gnomedvb import _
 from gnomedvb.ui.wizard.pages.BasePage import BasePage
 
 DVB_APPS_DIRS = ("/usr/share/dvb",
@@ -32,7 +33,9 @@ DVB_APPS_DIRS = ("/usr/share/dvb",
                  "/usr/share/doc/dvb-utils/examples/scan")
                  
 COUNTRIES = {
+    "ad": "Andorra",
     "at": "Austria",
+    "az": "Azerbaijan",
     "au": "Australia",
     "be": "Belgium",
     "ch": "Switzerland",
@@ -44,24 +47,86 @@ COUNTRIES = {
     "fr": "France",
     "gr": "Greece",
     "hk": "Hong Kong",
-    "hr": "Hungary",
+    "hr": "Croatia",
+    "hu": "Hungary",
+    "il": "Israel",
+    "ir": "Iran, Islamic Republic of",
     "is": "Iceland",
     "it": "Italy",
+    "lt": "Lithuania",
     "lu": "Luxemburg",
+    "lv": "Latvia",
     "nl": "Netherlands",
     "no": "Norway",
     "nz": "New Zealand",
     "pl": "Poland",
+    "ro": "Romania",
     "se": "Sweden",
+    "si": "Slovenia",
     "sk": "Slovakia",
     "tw": "Taiwan",
     "uk": "United Kingdom",
+    "vn": "Viet Nam",
 }
 
+COUNTRIES_DVB_T = (
+    "ad",
+    "at",
+    "az",
+    "au",
+    "be",
+    "ch",
+    "cz",
+    "de",
+    "dk",
+    "es",
+    "fi",
+    "fr",
+    "gr",
+    "hk",
+    "hr",
+    "hu",
+    "il",
+    "ir",
+    "is",
+    "it",
+    "lt",
+    "lu",
+    "lv",
+    "nl",
+    "no",
+    "nz",
+    "pl",
+    "ro",
+    "se",
+    "si",
+    "sk",
+    "tw",
+    "uk",
+    "vn",
+)
+
+COUNTRIES_DVB_C = (
+    "at",
+    "be",
+    "ch",
+    "cz",
+    "de",
+    "dk",
+    "es",
+    "fi",
+    "fr",
+    "hu",
+    "lu",
+    "nl",
+    "no",
+    "se",
+)
+
 class InitialTuningDataPage(BasePage):
     
     __gsignals__ = {
-            "finished": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [bool]),
+            "finished": (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE, [bool]),
     }
     NOT_LISTED = "00"
 
@@ -139,11 +204,8 @@ class InitialTuningDataPage(BasePage):
         self.providers_view = None
         
         countries = {self.NOT_LISTED: _("Not listed")}
-        country_codes = ("at", "au", "be", "ch", "cz", "de", "dk", "es", "fi", "fr",
-            "gr", "hr", "hk", "is", "it", "lu", "nl", "nz", "pl", "se", "sk",
-            "tw", "uk",)
         t = gettext.translation("iso_3166", fallback=True)
-        for lang in country_codes:
+        for lang in COUNTRIES_DVB_T:
             countries[lang] = t.ugettext(COUNTRIES[lang])
         
         self._create_table()
@@ -212,18 +274,17 @@ class InitialTuningDataPage(BasePage):
         
     def setup_dvb_c(self):
         countries = {}
-        country_codes = ("at", "be", "ch", "de", "fi", "lu", "nl", "se", "no",)
         t = gettext.translation("iso_3166", fallback=True)
-        for lang in country_codes:
+        for lang in COUNTRIES_DVB_C:
             countries[lang] = t.ugettext(COUNTRIES[lang])
-            
+
         self._create_table()
-            
+
         country = Gtk.Label()
         country.set_markup_with_mnemonic(_("_Country:"))
         country.show()
         self.table.attach(country, 0, 1, 0, 1, yoptions=0, xoptions=Gtk.AttachOptions.FILL)
-    
+
         self.countries = Gtk.ListStore(str, str)
         self.countries.set_sort_column_id(0, Gtk.SortType.ASCENDING)
         self.countries.set_sort_func(0, self.combobox_sort_func, None)
@@ -294,7 +355,7 @@ class InitialTuningDataPage(BasePage):
                 toplevel_window.set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
                 
                 # Fill list async
-                gobject.idle_add(self._fill_providers, selected_country)            
+                GObject.idle_add(self._fill_providers, selected_country)
 
     def _fill_providers(self, selected_country):
         # Only DVB-T has bruteforce scan
@@ -356,30 +417,24 @@ class InitialTuningDataPage(BasePage):
             for transmode in ["2k", "8k"]:
                 for guard in [0, 32, 16, 8, 4]:
                     self.__tuning_data.append(
-                        [freq,
-                         4, # hierarchy: AUTO
-                         7, # bandwidth
-                         transmode,
-                         "NONE", # code-rate-hp
-                         "AUTO", # code-rate-lp
-                         "QAM64", # constellation
-                         guard, # guard interval
-                        ])
+                        self.create_parameters_dict(freq, 7, transmode, guard))
 
         for chan in range(21, 70):
             freq = 306000000 + chan* 8000000
             for transmode in ["2k", "8k"]:
                 for guard in [32, 16, 8, 4]:
                     self.__tuning_data.append(
-                        [freq,
-                         4, # hierarchy: AUTO
-                         8, # bandwidth
-                         transmode,
-                         "NONE", # code-rate-hp
-                         "AUTO", # code-rate-lp
-                         "QAM64", # constellation
-                         guard, # guard interval
-                        ])
+                        self.create_parameters_dict(freq, 8, transmode, guard))
+
+    def create_parameters_dict(self, freq, bandwidth, transmode, guard):
+        return {"frequency": GLib.Variant('u', freq),
+            "hierarchy": GLib.Variant('u', 4), # AUTO
+            "bandwidth": GLib.Variant('u', bandwidth),
+            "transmission-mode": GLib.Variant('s', transmode),
+            "code-rate-hp": GLib.Variant('s', "NONE"),
+            "code-rate-lp": GLib.Variant('s', "AUTO"),
+            "constellation": GLib.Variant('s', "QAM64"),
+            "guard-interval": GLib.Variant('u', guard)}
 
     def combobox_sort_func(self, model, iter1, iter2, user_data):
         name1, code1 = model[iter1]
